window.Gleam.initSearch([{"doc":"lustre_tauri","title":"lustre_tauri","content":"# lustre_tauri\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_tauri)](https://hex.pm/packages/lustre_tauri)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_tauri/)\n\nUse [Tauri](https://tauri.app/) invoke commands from [Lustre](https://hex.pm/packages/lustre) via its `effect` interface.\n\nThe API and details are heavily based on [lustre_http](https://hexdocs.pm/lustre_http/index.html).\n\n&gt; [!NOTE]\n&gt; This library currently only supports invoke commands, not events\n\n---\n\n## Requirements\n\nThis requires that you have the [`@tauri-apps/api`](https://www.npmjs.com/package/@tauri-apps/api) package installed.\n\n## Example\n\n```gleam\nimport lustre\nimport lustre/attribute\nimport lustre/effect.{type Effect}\nimport lustre/element.{type Element}\nimport lustre/element/html\nimport lustre/event\nimport lustre_tauri.{type TauriError}\n\npub fn main() {\n    let app = lustre.application(init, update, view)\n}\n\ntype Model {\n    Model(name: String, message: String)\n}\n\nfn init(_) -&gt; #(Model, Effect(Msg)) {\n    #(Model(name: &quot;&quot;, message: &quot;&quot;), effect.none())\n}\n\npub opaque type Msg {\n    UpdateName(String)\n    GreetUser(Result(String, TauriError))\n    Greet\n}\n\nfn update(model: Model, msg: Msg) -&gt; #(Model, Effect(Msg)) {\n  case msg {\n    UpdateName(name) -&gt; #(Model(..model, name: name), effect.none())\n    GreetUser(Ok(message)) -&gt; #(\n      Model(..model, message: message),\n      effect.none(),\n    )\n    GreetUser(Error(_)) -&gt; #(model, effect.none())\n    Greet -&gt; #(model, greet(model.name))\n  }\n}\n\nfn greet(name: String) -&gt; Effect(Msg) {\n    lustre_tauri.invoke(\n        &quot;greet&quot;,\n        [],\n        lustre_tauri.expect_text(GreetUser)\n    )\n}\n\nfn view(model: Model) -&gt; Element(Msg) {\n  html.div([], [\n    html.h1([], [element.text(model.message)]),\n    html.input([\n      attribute.type_(&quot;text&quot;),\n      attribute.name(&quot;greet_name&quot;),\n      event.on_input(UpdateName),\n    ]),\n    html.button([event.on_click(Greet)], [element.text(&quot;Send your name!&quot;)]),\n  ])\n}\n```\n\n## Installation\n\nLike Lustre, this is published on [Hex](https://hex.pm/packages/lustre_tauri). \nYou can add it to your Gleam project via\n\n```sh\ngleam add lustre_tauri\n```\n\nYou will also need to install the `@tauri-apps/api`. This can be added to your \nproject through your preferred method:\n\n```sh\npnpm add @tauri-apps/api\nyarn add @tauri-apps/api\nnpm add @tauri-apps/api\n```\n\n## Development\n\n```sh\ngleam run   # Run the project\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/lustre_tauri&gt;.\n","url":"index.html"},{"doc":"lustre_tauri","title":"Expect","content":"pub opaque type Expect(msg)\n Defines how to handle the response from a Tauri command and convert it into\n a message for your application. You typically won&#39;t need to create this\n directly - instead use helpers like `expect_json` or `expect_text`.\n\nSynonyms:\nlustre_tauri.Expect\nlustre_tauri Expect","url":"lustre_tauri.html#Expect"},{"doc":"lustre_tauri","title":"TauriError","content":"pub type TauriError {\n  InvokeError(String)\n  DecodeError(List(dynamic.DecodeError))\n}\n Represents possible errors that can occur when working with Tauri commands.\nInvokeError(String)\n Returned when a Tauri command fails during execution\n\nDecodeError(List(dynamic.DecodeError))\n Returned when the response from a Tauri command cannot be decoded into\n the expected Gleam type\n\nSynonyms:\nlustre_tauri.TauriError\nlustre_tauri TauriError","url":"lustre_tauri.html#TauriError"},{"doc":"lustre_tauri","title":"expect_anything","content":"pub fn expect_anything(\n  to_msg: fn(Result(Nil, TauriError)) -&gt; a,\n) -&gt; Expect(a)\n Used when you only need to confirm a command succeeded and don&#39;t care about\n its response data. Perfect for fire-and-forget operations like saving files\n or updating settings.\nSynonyms:\nlustre_tauri.expect_anything\nlustre_tauri expect_anything","url":"lustre_tauri.html#expect_anything"},{"doc":"lustre_tauri","title":"expect_json","content":"pub fn expect_json(\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  to_msg: fn(Result(a, TauriError)) -&gt; b,\n) -&gt; Expect(b)\n Handle commands that return structured data. Uses a decoder to convert the\n response into a type-safe Gleam value. This is great for commands that\n return complex data structures like database queries or system information.\n\n ### Example\n \n type SystemInfo {\n   SystemInfo(os: String, memory: Int, cpu_cores: Int)\n }\n\n fn get_system_info() {\n   let decoder = dynamic.decode3(\n     SystemInfo,\n     dynamic.field(&quot;os&quot;, dynamic.string),\n     dynamic.field(&quot;memory&quot;, dynamic.int),\n     dynamic.field(&quot;cpu_cores&quot;, dynamic.int)\n   )\n   \n   tauri.invoke(&quot;get_system_info&quot;, [], tauri.expect_json(decoder, GotSystemInfo))\n }\n \nSynonyms:\nlustre_tauri.expect_json\nlustre_tauri expect_json","url":"lustre_tauri.html#expect_json"},{"doc":"lustre_tauri","title":"expect_text","content":"pub fn expect_text(\n  to_msg: fn(Result(String, TauriError)) -&gt; a,\n) -&gt; Expect(a)\n Handle commands that return text responses, such as reading file contents\n or getting simple string values from your Tauri backend.\nSynonyms:\nlustre_tauri.expect_text\nlustre_tauri expect_text","url":"lustre_tauri.html#expect_text"},{"doc":"lustre_tauri","title":"invoke","content":"pub fn invoke(\n  command: String,\n  args: List(#(String, a)),\n  expect: Expect(b),\n) -&gt; Effect(b)\n Execute a Tauri command and handle its response. The command name should match\n one defined in your Tauri backend, and arguments are passed as key-value pairs.\n\n ### Example\n \n import lustre_tauri as tauri\n\n type Msg {\n   FilesSaved(Result(Nil, tauri.TauriError))\n }\n\n fn save_files(paths: List(String)) {\n   tauri.invoke(\n     &quot;save_files&quot;,\n     [#(&quot;paths&quot;, paths)],\n     tauri.expect_anything(FilesSaved)\n   )\n }\n \nSynonyms:\nlustre_tauri.invoke\nlustre_tauri invoke","url":"lustre_tauri.html#invoke"},{"doc":"lustre_tauri","title":"lustre_tauri","content":"","url":"lustre_tauri.html"}]);